==> azureml_train_widgets-0.1.58-py3-none-any.whl: azureml/train/widgets/_universal_widgets.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------

"""Widgets classes used by platforms supporting non-interactive HTML widgets."""
import datetime
import jinja2
import base64
import uuid


def _walk_and_update_time_object(d):
    if isinstance(d, dict):
        for k, v in d.items():
            _walk_and_update_time_object(v)
            if isinstance(v, datetime.datetime):
                d[k] = v.isoformat()
    elif isinstance(d, list):
        for x in d:
            _walk_and_update_time_object(x)


class _RunWidgetBase:
    """Base class for run widget."""

    runType = ''
    widget_settings = ''
    selected_run_id = ''
    run_properties = ''
    run_logs = ''
    run_metrics = ''
    run_id = ''
    run_arguments = ''
    child_runs = ''
    child_runs_metrics = ''
    workbench_uri = ''

    # TODO move all js/css to our own CDN
    frame = """<!DOCTYPE html>
            <meta charset="utf-8">
            <head>
              <link rel="stylesheet" type="text/css" href="https://cdn.jupyter.org/notebook/5.3.1/style/style.min.css">
            </head>
            <body>
            <div id='{{GUID}}'></div>
            <script src="https://cdnjs.cloudflare.com/ajax/libs/require.js/2.3.5/require.js"></script>
            <script
                src="https://code.jquery.com/jquery-3.3.1.min.js"
                integrity="sha256-FgpCb/KJQlLNfOu91ta32o/NMZxltwRo8QtmkMRdAu8="
                crossorigin="anonymous"></script>
            <script>
                if (window.require) {
                    window.require.config({
                        map: {
                            "*" : {
                                "azureml_contrib_widgets": "files/customjs/index",
                            }
                        }
                    });
                }
                require(["azureml_contrib_widgets"], function(widgets){
                    // backfill python preserved words
                    var False = false;
                    var True = true;
                    var None = null;
                    var id = '{{GUID}}';
                    runType = '{{runType}}';
                    value = {{value}};

                    value.run_logs = atob(value.run_logs);
                    if(runType==='HyperDrive'){
                        widgets.ShowHyperDriveRunsView.prototype.render(value, $('#'+id));
                    }
                    else if (runType==='AutoML'){
                        widgets.ShowAutoMLRunsView.prototype.render(value, $('#'+id));
                    }
                    else{
                        widgets.ShowRunDetailsView.prototype.render(value, $('#'+id));
                    }
                })
            </script>"""

    def get_html(self):
        """Return HTML string representation of the widget to be rendered by the platform."""
        value = {
            "widget_settings": self.widget_settings,
            "selected_run_id": self.selected_run_id,
            "run_properties": self.run_properties,
            # decode in the end is to remove b''
            "run_logs": base64.b64encode(bytearray(self.run_logs.encode())).decode(),
            "run_metrics": self.run_metrics,
            "run_id": self.run_id,
            "run_arguments": self.run_arguments,
            "child_runs": self.child_runs,
            "child_runs_metrics": self.child_runs_metrics,
            "workbench_uri": self.workbench_uri
        }
        # can't serialize datetime object so modify them to ISO string
        _walk_and_update_time_object(value)
        template = jinja2.Template(self.frame)
        return template.render(runType=self.runType, value=value, GUID=uuid.uuid4())


class _AutoML(_RunWidgetBase):
    """AutoML widget object."""

    runType = "AutoML"


class _HyperDrive(_RunWidgetBase):
    """Hyperdrive widget object."""

    runType = "HyperDrive"


class _UserRun(_RunWidgetBase):
    """Single run widget object."""

    runType = "UserRun"

==> azureml_train_widgets-0.1.74-py3-none-any.whl: azureml/train/widgets/_universal_widgets.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------

"""Widgets classes used by platforms supporting non-interactive HTML widgets."""
import datetime
import jinja2
import base64
import uuid


def _walk_and_update_time_object(d):
    if isinstance(d, dict):
        for k, v in d.items():
            _walk_and_update_time_object(v)
            if isinstance(v, datetime.datetime):
                d[k] = v.isoformat()
    elif isinstance(d, list):
        for x in d:
            _walk_and_update_time_object(x)


class _RunWidgetBase:
    """Base class for run widget."""

    runType = ''
    widget_settings = ''
    selected_run_id = ''
    run_properties = ''
    run_logs = ''
    run_metrics = ''
    run_id = ''
    run_arguments = ''
    child_runs = ''
    child_runs_metrics = ''
    workbench_uri = ''
    graph = ''

    # TODO move all js/css to our own CDN
    frame = """<!DOCTYPE html>
            <meta charset="utf-8">
            <head>
              <link rel="stylesheet" type="text/css" href="https://cdn.jupyter.org/notebook/5.3.1/style/style.min.css">
            </head>
            <body>
            <div id='{{GUID}}'></div>
            <script src="https://cdnjs.cloudflare.com/ajax/libs/require.js/2.3.5/require.js"></script>
            <script
                src="https://code.jquery.com/jquery-3.3.1.min.js"
                integrity="sha256-FgpCb/KJQlLNfOu91ta32o/NMZxltwRo8QtmkMRdAu8="
                crossorigin="anonymous"></script>
            <script>
                if (window.require) {
                    window.require.config({
                        map: {
                            "*" : {
                                "azureml_contrib_widgets": "files/customjs/index",
                            }
                        }
                    });
                }
                require(["azureml_contrib_widgets"], function(widgets){
                    // backfill python preserved words
                    var False = false;
                    var True = true;
                    var None = null;
                    var id = '{{GUID}}';
                    runType = '{{runType}}';
                    value = {{value}};

                    value.run_logs = atob(value.run_logs);
                    if(runType==='HyperDrive'){
                        widgets.ShowHyperDriveRunsView.prototype.render(value, $('#'+id));
                    }
                    else if (runType==='AutoML'){
                        widgets.ShowAutoMLRunsView.prototype.render(value, $('#'+id));
                    }
                    else{
                        widgets.ShowRunDetailsView.prototype.render(value, $('#'+id));
                    }
                })
            </script>"""

    def get_html(self):
        """Return HTML string representation of the widget to be rendered by the platform."""
        value = {
            "widget_settings": self.widget_settings,
            "selected_run_id": self.selected_run_id,
            "run_properties": self.run_properties,
            # decode in the end is to remove b''
            "run_logs": base64.b64encode(bytearray(self.run_logs.encode())).decode(),
            "run_metrics": self.run_metrics,
            "run_id": self.run_id,
            "run_arguments": self.run_arguments,
            "child_runs": self.child_runs,
            "child_runs_metrics": self.child_runs_metrics,
            "workbench_uri": self.workbench_uri,
            'graph': self.graph
        }
        # can't serialize datetime object so modify them to ISO string
        _walk_and_update_time_object(value)
        template = jinja2.Template(self.frame)
        return template.render(runType=self.runType, value=value, GUID=uuid.uuid4())


class _AutoML(_RunWidgetBase):
    """AutoML widget object."""

    runType = "AutoML"


class _HyperDrive(_RunWidgetBase):
    """Hyperdrive widget object."""

    runType = "HyperDrive"


class _UserRun(_RunWidgetBase):
    """Single run widget object."""

    runType = "UserRun"


class _Pipeline(_RunWidgetBase):
    """Single run widget object."""

    runType = "Pipeline"
